****************************
Experimental ``asyncio`` API
****************************

.. note::

   This page isn't rendered on readthedocs since it requires Python 3.5.
   `The rendered page can be found here`_.

.. warning::

   The ``asyncio`` API is not thoroughly unit tested, use with caution. Please
   report issues on `GitHub`_.

.. _`GitHub`: https://github.com/python-astrodynamics/spacetrack

.. _`The rendered page can be found here`: http://pythonhosted.org/spacetrack/
   modules/aio.html

.. automodule:: spacetrack.aio
   :members:
   :show-inheritance:
